==> charcoal-0.8.0.tar.gz: charcoal-0.8.0/web_app/03_pear_db/classes/page_selectors/MyPageSelector.class.php <==
<?php
/**
* ڡ쥯
*
* PHP version 5
*
* @package    renderers
* @author     stk2k <stk2k@sazysoft.com>
* @copyright  2008 stk2k, sazysoft
*/

class MyPageSelector extends PageSelector implements IPageSelector
{

	/*
	 *	󥹥ȥ饯
	 */
	public function __construct( String $name = NULL )
	{
		parent::__construct(s($name));
	}

	/**
	 *   ڡꤹ
	 */
	public function selectPage( String $proc_name, ITaskManager $task_manager, Response $response )
	{
		switch( $proc_name ){
		case 'index':
			{
				// ³åξֳǧ
				$connect_check_task = $task_manager->getTask( s('db_connect_check') );
				$table_check_task = $task_manager->getTask( s('db_table_check') );
				if ( !$connect_check_task->success->isTrue() || !$table_check_task->success->isTrue() ){
					// ³ǤʤХåȥåײ̡ʥƥåףˤɽ
					$response->set( 'template_name', 'setup.tpl' );
					$response->set( 'step', '1' );
				}
				else{
					// ³Ǥ龦ʰ̤ɽ
					$shouhin_list_task = $task_manager->getTask( s('shouhin_list') );
					$response->set( 'shouhin_list', $shouhin_list_task->shouhin_list );
					$response->set( 'template_name', 'shouhin.tpl' );

					// ᡼򸡺
					$manufacturer_list_task = $task_manager->getTask( s('manufacturer_list') );
					$response->set( 'manufacturer_list', $manufacturer_list_task->manufacturer_list );
				}
			}
			break;
		case 'shouhin_add':
		case 'shouhin_del':
		case 'shouhin_update':
			{
				// ʰ̤ɽ
				$shouhin_list_task = $task_manager->getTask( s('shouhin_list') );
				$response->set( 'shouhin_list', $shouhin_list_task->shouhin_list );
				$response->set( 'template_name', 'shouhin.tpl' );

				// ᡼򸡺
				$manufacturer_list_task = $task_manager->getTask( s('manufacturer_list') );
				$response->set( 'manufacturer_list', $manufacturer_list_task->manufacturer_list );
			}
			break;
		case 'shouhin_edit':
			{
				// Խ̤ɽ
				$shouhin_edit_task = $task_manager->getTask( s('shouhin_edit') );
				$response->set( 'shouhin', $shouhin_edit_task->shouhin );
				$response->set( 'template_name', 'shouhin_edit.tpl' );

				// ᡼򸡺
				$manufacturer_list_task = $task_manager->getTask( s('manufacturer_list') );
				$response->set( 'manufacturer_list', $manufacturer_list_task->manufacturer_list );
			}
			break;
		case 'db_connect':
			{
				// ³ƥȥξֳǧ
				$db_check_task = $task_manager->getTask( s('db_connect_check') );
				if ( !$db_check_task->success ){
					// ³ǤʤХåȥåײ̤ɽ
					$response->set( 'template_name', 'setup.tpl' );
					$response->set( 'step', '1' );
				}
				else{
					// ³Ǥ饹ƥåףɽ
					$response->set( 'template_name', 'setup_step2.tpl' );
					$response->set( 'step', '2' );
				}
			}
			break;
		case 'db_create':
			{
				// 󥹥󥹥åξֳǧ
				$instance_check_task = $task_manager->getTask( s('db_instance_check') );
				if ( !$instance_check_task->success ){
					// ³ǤʤХåȥåײ̤ɽ
					$response->set( 'template_name', 'setup.tpl' );
					$response->set( 'step', '1' );
				}
				else{
					// 󥹥󥹺
					$instance_create_task = $task_manager->getTask( s('db_instance_create') );

					// ǡ١̾
					$db_name = $instance_create_task->db_name;

					// ǡ١̾
					$response->set( "db_name", $db_name );

					// ƥåףɽ
					$response->set( 'template_name', 'setup_step3.tpl' );
					$response->set( 'step', '3' );
				}
			}
			break;
		case 'tbl_create':
			{
				// ơ֥ξֳǧ
				$table_create_task = $task_manager->getTask( s('db_table_create') );
				if ( !$table_create_task->success->isTrue() ){
					// ³ǤʤХåȥåײ̤ɽ
					$response->set( 'template_name', 'setup.tpl' );
					$response->set( 'step', '1' );
				}
				else{
					// ƥåףɽ
					$response->set( 'template_name', 'setup_step4.tpl' );
					$response->set( 'step', '4' );
				}
			}
			break;
		}

		return s('top_page.tpl');
	}
}

==> charcoal-0.9.0.tar.gz: charcoal-0.9.0/web_app/03_pear_db/classes/page_selectors/MyPageSelector.class.php <==
<?php
/**
* ڡ쥯
*
* PHP version 5
*
* @package    renderers
* @author     stk2k <stk2k@sazysoft.com>
* @copyright  2008 stk2k, sazysoft
*/

class MyPageSelector extends PageSelector implements IPageSelector
{

	/*
	 *	󥹥ȥ饯
	 */
	public function __construct( String $name = NULL )
	{
		parent::__construct(s($name));
	}

	/**
	 *   ڡꤹ
	 */
	public function selectPage( String $proc_name, ITaskManager $task_manager, Response $response )
	{
		switch( $proc_name ){
		case 'index':
			{
				// ³åξֳǧ
				$connect_check_task = $task_manager->getTask( s('db_connect_check') );
				$table_check_task = $task_manager->getTask( s('db_table_check') );
				if ( !$connect_check_task->success || !$table_check_task->success ){
					// ³ǤʤХåȥåײ̡ʥƥåףˤɽ
					$response->set( 'template_name', 'setup.tpl' );
					$response->set( 'step', '1' );
				}
				else{
					// ³Ǥ龦ʰ̤ɽ
					$shouhin_list_task = $task_manager->getTask( s('shouhin_list') );
					$response->set( 'shouhin_list', $shouhin_list_task->shouhin_list );
					$response->set( 'template_name', 'shouhin.tpl' );

					// ᡼򸡺
					$manufacturer_list_task = $task_manager->getTask( s('manufacturer_list') );
					$response->set( 'manufacturer_list', $manufacturer_list_task->manufacturer_list );
				}
			}
			break;
		case 'shouhin_add':
		case 'shouhin_del':
		case 'shouhin_update':
			{
				// ʰ̤ɽ
				$shouhin_list_task = $task_manager->getTask( s('shouhin_list') );
				$response->set( 'shouhin_list', $shouhin_list_task->shouhin_list );
				$response->set( 'template_name', 'shouhin.tpl' );

				// ᡼򸡺
				$manufacturer_list_task = $task_manager->getTask( s('manufacturer_list') );
				$response->set( 'manufacturer_list', $manufacturer_list_task->manufacturer_list );
			}
			break;
		case 'shouhin_edit':
			{
				// Խ̤ɽ
				$shouhin_edit_task = $task_manager->getTask( s('shouhin_edit') );
				$response->set( 'shouhin', $shouhin_edit_task->shouhin );
				$response->set( 'template_name', 'shouhin_edit.tpl' );

				// ᡼򸡺
				$manufacturer_list_task = $task_manager->getTask( s('manufacturer_list') );
				$response->set( 'manufacturer_list', $manufacturer_list_task->manufacturer_list );
			}
			break;
		case 'db_connect':
			{
				// ³ƥȥξֳǧ
				$db_check_task = $task_manager->getTask( s('db_connect_check') );
				if ( !$db_check_task->success ){
					// ³ǤʤХåȥåײ̤ɽ
					$response->set( 'template_name', 'setup.tpl' );
					$response->set( 'step', '1' );
				}
				else{
					// ³Ǥ饹ƥåףɽ
					$response->set( 'template_name', 'setup_step2.tpl' );
					$response->set( 'step', '2' );
				}
			}
			break;
		case 'db_create':
			{
				// 󥹥󥹥åξֳǧ
				$instance_check_task = $task_manager->getTask( s('db_instance_check') );
				if ( !$instance_check_task->success ){
					// ³ǤʤХåȥåײ̤ɽ
					$response->set( 'template_name', 'setup.tpl' );
					$response->set( 'step', '1' );
				}
				else{
					// 󥹥󥹺
					$instance_create_task = $task_manager->getTask( s('db_instance_create') );

					// ǡ١̾
					$db_name = $instance_create_task->db_name;

					// ǡ١̾
					$response->set( "db_name", $db_name );

					// ƥåףɽ
					$response->set( 'template_name', 'setup_step3.tpl' );
					$response->set( 'step', '3' );
				}
			}
			break;
		case 'tbl_create':
			{
				// ơ֥ξֳǧ
				$table_create_task = $task_manager->getTask( s('db_table_create') );
				if ( !$table_create_task->success ){
					// ³ǤʤХåȥåײ̤ɽ
					$response->set( 'template_name', 'setup.tpl' );
					$response->set( 'step', '1' );
				}
				else{
					// ƥåףɽ
					$response->set( 'template_name', 'setup_step4.tpl' );
					$response->set( 'step', '4' );
				}
			}
			break;
		}

		return s('top_page.tpl');
	}
}
